/*!	\file		Cicada.cpp
	\author		Garth Santor
	\date		2017-01-05, 2019-02-12
	\version	1.0.0

	Cycada Cycles solution in C++.
*/

#include <iostream>
using namespace std;


int constexpr MAX_CICADA_CYCLES = 20;



/*!	Count the number of years that the cicada will coincide with predators.

	\param kCicadaCycle [in] the number of years in the cicada's life cycle.
	\param kTrialYears [in] the number of years to test against the cicada's cycle.
	\return the number of predators that align with the cicada's life cycle.
*/
uintmax_t num_predators(uintmax_t const kCicadaCycle, uintmax_t const kTrialYears) {
	uintmax_t predatorCount = 0;
	for (uintmax_t year = 1; year <= kTrialYears; ++year) {
		if (year%kCicadaCycle == 0) {
			predatorCount += ((year % 2) == 0);
			predatorCount += ((year % 3) == 0);
			predatorCount += ((year % 4) == 0);
			predatorCount += ((year % 6) == 0);
		}
	}
	return predatorCount;
}



/*!	Process entry point - run the cicada trials.
*/
int main() {
	// Query the user for the number of trials to perform.
	cout << "Enter the number of years to test: ";
	uintmax_t trialYears;
	cin >> trialYears;


	// Output a table of trial results.
	cout << "cicada cycle\t#predators" << endl;
	for (uintmax_t cicadaCycle = 1; cicadaCycle <= MAX_CICADA_CYCLES; ++cicadaCycle)
		cout << cicadaCycle << "\t\t" << num_predators(cicadaCycle, trialYears) << endl;
}